<?xml version="1.0" encoding="UTF-8"?>
<!--
   Copyright 2014 Anyware Services

   Licensed under the Apache License, Version 2.0 (the "License");
   you may not use this file except in compliance with the License.
   You may obtain a copy of the License at

       http://www.apache.org/licenses/LICENSE-2.0

   Unless required by applicable law or agreed to in writing, software
   distributed under the License is distributed on an "AS IS" BASIS,
   WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
   See the License for the specific language governing permissions and
   limitations under the License.
   -->
   
<xsl:stylesheet version="1.0" 
	xmlns:xsl="http://www.w3.org/1999/XSL/Transform" 
	xmlns:docbook="http://docbook.org/ns/docbook" 
    xmlns:i18n="http://apache.org/cocoon/i18n/2.1"
    xmlns:math="http://exslt.org/math" 
    xmlns:ametys="org.ametys.web.transformation.xslt.AmetysXSLTHelper"
    xmlns:subscribe="org.ametys.plugins.pagesubscription.helpers.PageSubscriptionXSLTHelper"
    exclude-result-prefixes="docbook"
    extension-element-prefixes="math ametys">

   	<xsl:import href="plugin:web://stylesheets/helper/common_3.3.xsl"/>
    
    <xsl:variable name="uniqueId" select="concat('page_subscribe_', substring-after(math:random(), '.'))"/>
    <xsl:variable name="page-subscribe-page-id" select="ametys:pageId()"/>
   
    <xsl:template name="page-subscribe-form-get-url">
        <xsl:value-of select="concat(ametys:siteUriPrefix(), '/', ametys:lang(), '/_plugins/page-subscription/page/subscribe')"/>
    </xsl:template>   
    
   	<xsl:template name="page-subscription">
   	    <xsl:choose>
   	        <xsl:when test="ametys:isCacheable()">
   	            <xsl:call-template name="page-subscription-form-cacheable"/>
   	        </xsl:when>
   	        <xsl:otherwise>
   	            <xsl:call-template name="page-subscription-form"/>
   	        </xsl:otherwise>
   	    </xsl:choose>
        <xsl:call-template name="page-subscribe-popup-info-script"/>
    	<xsl:call-template name="page-subscription-message"/>       	    
   	</xsl:template>
   	
   	<xsl:template name="page-subscription-form-cacheable">
   	    <xsl:call-template name="page-handle-subscribe-form-cacheable"/>
        
	    <xsl:call-template name="page-subscribe-script-cacheable"/>
        <xsl:call-template name="page-subscribe-link-script-submit" />
        <xsl:call-template name="page-subscribe-form-script"/>
   	</xsl:template>
   	
   	<xsl:template name="page-subscription-form">
        <xsl:call-template name="page-handle-subscribe-form"/>
        
   	    <xsl:variable name="foUser" select="ametys:user()"/>
   	    <xsl:variable name="email"><xsl:if test="$foUser"><xsl:value-of select="$foUser/user/email"/></xsl:if></xsl:variable>
        <xsl:if test="$email != ''">
            <xsl:choose>
                <xsl:when test="subscribe:isPageSubscriber($email)">
                    <xsl:call-template name="page-unsubscribe-link">
                        <xsl:with-param name="email" select="$email"/>
                    </xsl:call-template>
                </xsl:when>
                <xsl:otherwise>
                    <xsl:call-template name="page-subscribe-link">
                        <xsl:with-param name="email" select="$email"/>
                    </xsl:call-template>
                </xsl:otherwise>
          </xsl:choose>
        </xsl:if>
    </xsl:template>
    
    <xsl:template name="page-subscribe-link">
        <xsl:param name="email"/>
        
        <xsl:call-template name="page-subscribe-link-script">
            <xsl:with-param name="email" select="$email"/>
        </xsl:call-template>
        <xsl:call-template name="page-subscribe-link-script-submit" />
        
	    <div class="page-subscribe"> 
	         <p id="page-subscribe-link-{$uniqueId}" style="display: none"><i18n:text i18n:key="PLUGINS_PAGE_SUBSCRIBE_POPUP_SUBSCRIBE_TITLE" i18n:catalogue="plugin.page-subscription"/></p>
	    
		     <script type="text/javascript">
		         $j("#page-subscribe-link-<xsl:value-of select="$uniqueId"/>").wrapInner("&lt;a href=\"javascript: page_subscribe_popup_<xsl:value-of select="$uniqueId"/>('subscribe')\"&gt;&lt;/a&gt;");
		         $j("#page-subscribe-link-<xsl:value-of select="$uniqueId"/>").css('display', '');
		         $j("#page-subscribe-<xsl:value-of select="$uniqueId"/>").css('display', 'none');
		     </script>
		     	
	         <div id="page-subscribe-confirm-{$uniqueId}" style="display: none">
                 <p><i18n:text i18n:key="PLUGINS_PAGE_SUBSCRIBE_POPUP_SUBSCRIBE_DESC" i18n:catalogue="plugin.page-subscription"/></p>         
             </div>
	    </div>
    </xsl:template>
    
    <xsl:template name="page-unsubscribe-link">
        <xsl:param name="email"/>
        
        <xsl:call-template name="page-subscribe-link-script">
            <xsl:with-param name="email" select="$email"/>
        </xsl:call-template>
        
        <div class="page-subscribe"> 
            <p id="page-subscribe-link-{$uniqueId}" style="display: none"><i18n:text i18n:key="PLUGINS_PAGE_SUBSCRIBE_POPUP_UNSUBSCRIBE_TITLE" i18n:catalogue="plugin.page-subscription"/></p>
        
            <script type="text/javascript">
                $j("#page-subscribe-link-<xsl:value-of select="$uniqueId"/>").wrapInner("&lt;a href=\"javascript: page_subscribe_popup_<xsl:value-of select="$uniqueId"/>('unsubscribe')\"&gt;&lt;/a&gt;");
                $j("#page-subscribe-link-<xsl:value-of select="$uniqueId"/>").css('display', '');
                $j("#page-subscribe-<xsl:value-of select="$uniqueId"/>").css('display', 'none');
            </script>

            <div id="page-subscribe-confirm-{$uniqueId}" style="display: none">
                <p><i18n:text i18n:key="PLUGINS_PAGE_SUBSCRIBE_POPUP_UNSUBSCRIBE_DESC" i18n:catalogue="plugin.page-subscription"/></p>
            </div>
        </div>
    </xsl:template>
    
    <xsl:template name="page-handle-subscribe-form">          
        <xsl:call-template name="page-subscribe-form-script"/>
        
        <div class="page-subscribe"> 
	        <p id="page-subscribe-{$uniqueId}"><i18n:text i18n:key="PLUGINS_PAGE_SUBSCRIBE_FORM_TITLE" i18n:catalogue="plugin.page-subscription"/></p>
            
            <xsl:call-template name="page-subscribe-form"/>
   
            <script type="text/javascript">
               $j("#page-subscribe-<xsl:value-of select="$uniqueId"/>").wrapInner("&lt;a href='javascript: page_subscribe_form_popup_<xsl:value-of select="$uniqueId"/>()'&gt;&lt;/a&gt;");
               $j("#page-subscribe-form-<xsl:value-of select="$uniqueId"/>").css('display', 'none');
               $j("#page-subscribe-submit-<xsl:value-of select="$uniqueId"/>").css('display', 'none');
            </script>
       </div>         
    </xsl:template>
    
    <xsl:template name="page-handle-subscribe-form-cacheable">                  
        <div class="page-subscribe"> 
            <p id="page-subscribe-{$uniqueId}"><i18n:text i18n:key="PLUGINS_PAGE_SUBSCRIBE_FORM_TITLE" i18n:catalogue="plugin.page-subscription"/></p>         
            <xsl:call-template name="page-subscribe-form"/>
            
            <div id="page-subscribe-confirm-subscribe-{$uniqueId}" style="display: none">
                <p><i18n:text i18n:key="PLUGINS_PAGE_SUBSCRIBE_POPUP_HANDLE_SUBSCRIBE_DESC" i18n:catalogue="plugin.page-subscription"/></p>
            </div>
            
            <div id="page-subscribe-confirm-unsubscribe-{$uniqueId}" style="display: none">
                <p><i18n:text i18n:key="PLUGINS_PAGE_SUBSCRIBE_POPUP_HANDLE_UNSUBSCRIBE_DESC" i18n:catalogue="plugin.page-subscription"/></p>
            </div>
       </div>         
    </xsl:template>
    
    <xsl:template name="page-subscribe-form">
        <xsl:variable name="page-subscribe-form-url"><xsl:call-template name="page-subscribe-form-get-url"/></xsl:variable>    
    
        <form id="page-subscribe-form-{$uniqueId}" action="{$page-subscribe-form-url}" method="post">
            <div id="page-subscribe-form-{$uniqueId}" class="page-subscribe-form">
               <input type="hidden" name="page-id" id="page-subscribe-{$uniqueId}-id" value="{$page-subscribe-page-id}"/>                    
            
               <xsl:call-template name="page-subscribe-form-field-mail"/>
               <xsl:call-template name="page-subscribe-form-field-action"/>  
               <xsl:call-template name="page-subscribe-form-field-submit"/>                     
            </div>
        </form>
    </xsl:template>
    
    <xsl:template name="page-subscribe-form-field-mail">
        <div class="field">
            <div class="label">
                <label for="page-subscribe-{$uniqueId}-email">
                    <i18n:text i18n:key="PLUGINS_PAGE_SUBSCRIBE_FORM_MAIL" i18n:catalogue="plugin.page-subscription"/>
                    <xsl:call-template name="page-subscribe-form-mandatorymarker"/>
                </label>
            </div>
            <div class="input">
                <input type="text" name="email" id="page-subscribe-{$uniqueId}-email"/>
            </div>
            <div class="field-end"></div>
        </div>
    </xsl:template>
    
    <xsl:template name="page-subscribe-form-field-action">
        <div class="field">
            <div class="input">
                <input type="radio" name="page-subscribe-action" id="page-subscribe-{$uniqueId}-action-subscribe" checked="true" value="subscribe"/>
                <label for="page-subscribe-{$uniqueId}-action-subscribe">
                    <i18n:text i18n:key="PLUGINS_PAGE_SUBSCRIBE_FORM_RADIO_SUBSCRIBE" i18n:catalogue="plugin.page-subscription"/>
                </label>
            </div>
	        <div class="field-end"></div>        
        </div>
        <div class="field">
            <div class="input">
                <input type="radio" name="page-subscribe-action" id="page-subscribe-{$uniqueId}-action-unsubscribe" value="unsubscribe" />
                <label for="page-subscribe-{$uniqueId}-action-unsubscribe">
                    <i18n:text i18n:key="PLUGINS_PAGE_SUBSCRIBE_FORM_RADIO_UNSUBSCRIBE" i18n:catalogue="plugin.page-subscription"/>
                </label>
            </div>
            <div class="field-end"></div>
        </div>    
    </xsl:template>
    
    <xsl:template name="page-subscribe-form-field-submit">
         <div id="page-subscribe-submit-{$uniqueId}">
             <xsl:call-template name="common-utils-input-submit">
                 <xsl:with-param name="i18nkey" select="'plugin.page-subscription:PLUGINS_PAGE_SUBSCRIBE_FORM_VALIDATE'" />                
             </xsl:call-template>
         </div>
    </xsl:template>
    
    <xsl:template name="page-subscribe-form-mandatorymarker">
        <span class="mandatory-marker">
            <i18n:text i18n:key="PLUGINS_WEB_FRONTOFICE_MANDATORY_FIELD" i18n:catalogue="plugin.web"/>
        </span>
    </xsl:template> 
    
    <xsl:template name="page-subscription-message">
        <div id="page-subscribe-message-subscribe-{$uniqueId}" style="display: none">
            <p><i18n:text i18n:key="PLUGINS_PAGE_SUBSCRIBE_FORM_SUBSCRIBE_OK" i18n:catalogue="plugin.page-subscription"/></p>
        </div>
        <div id="page-subscribe-message-unsubscribe-{$uniqueId}" style="display: none">
            <p><i18n:text i18n:key="PLUGINS_PAGE_SUBSCRIBE_FORM_UNSUBSCRIBE_OK" i18n:catalogue="plugin.page-subscription"/></p>
        </div>
    </xsl:template>
    
    <xsl:template name="page-subscribe-form-script">
         <script type="text/javascript">
             function page_subscribe_form_popup_<xsl:value-of select="$uniqueId"/>()
             {
                 $j("#page-subscribe-form-<xsl:value-of select="$uniqueId"/>").dialog({
                   resizable: false,
                   height: 'auto',
                   width: 'auto',
                   modal: true,
                   title: '<i18n:text i18n:key="PLUGINS_PAGE_SUBSCRIBE_FORM_TITLE" i18n:catalogue="plugin.page-subscription"/>',
                   buttons: {
                     <i18n:text i18n:key="PLUGINS_PAGE_SUBSCRIBE_FORM_VALIDATE" i18n:catalogue="plugin.page-subscription"/>: function() {
                       page_subscribe_form_submit_<xsl:value-of select="$uniqueId"/>();
                     },
                     <i18n:text i18n:key="PLUGINS_PAGE_SUBSCRIBE_FORM_CANCEL" i18n:catalogue="plugin.page-subscription"/>: function() {
                       $j( this ).dialog( "close" );
                     }
                   }
                 });
                 
                 $j('#page-subscribe-<xsl:value-of select="$uniqueId"/>-email').val('');
             }
             
             function page_subscribe_form_submit_<xsl:value-of select="$uniqueId"/>()
             {                    
                 var pageId =  $j('#page-subscribe-<xsl:value-of select="$uniqueId"/>-id');
                 var emailInput = $j('#page-subscribe-<xsl:value-of select="$uniqueId"/>-email');
                 var action = $j('input:radio[name="page-subscribe-action"]:checked');

                 var errors = false;
                 
                 if (!/^([a-z0-9._-]+@[a-z0-9.-]{2,}[.][a-z]{2,})?$/.test(emailInput.val()) || /^\s*$/.test(emailInput.val()))
                 {
                     errors = true;
                     emailInput.parentsUntil('.field').parent().addClass('error');
                 }
                 else
                 {
                     emailInput.parentsUntil('.field').parent().removeClass('error');
                 }

                 if (!errors)
                 {
                     // send it in ajax
                     var data = {
                         "page-id": pageId.val(),
                         "email": emailInput.val(),
                         "page-subscribe-action": action.val(),
                         "ajax": "true"
                     };

                     function result(data)
                     {
                         var s = "";
                         $j('errors error', data).each(function () { s += $j(this).text() + "\n"; });
                         if (s == "")
                         {
                             var errors = $j('error', data);
                             if (errors.size() == 0)
                             {
                                 $j("#page-subscribe-form-<xsl:value-of select="$uniqueId"/>").dialog("close");
                                 show_popup_info_<xsl:value-of select="$uniqueId"/>(action);                 
                             }
                             else
                             {
                                 var errorInfo = "";
                                 $j.each(errors, function(i) {
                                     errorInfo += "\n* " + $j(errors[i]).text();
                                 }); 
                                 alert("<i18n:text i18n:key="PLUGINS_PAGE_SUBSCRIBE_FORM_ERROR_DESCRIPTION"  i18n:catalogue="plugin.page-subscription"/>" + errorInfo)
                             }
                         }
                         else
                         {
                             alert(s);
                         }
                     }
                     
                     function handleError(jqXHR, textStatus, errorThrown)
                     {
                         alert("<i18n:text i18n:key="PLUGINS_PAGE_SUBSCRIBE_FORM_ERROR_AJAX" i18n:catalogue="plugin.page-subscription"/>");
                     }

                     $j.ajax({
                         url: "<xsl:value-of select="$uri-prefix"/>/plugins/page-subscription/subscribe",
                         data: data,
                         type: 'post',
                         success: result,
                         error: handleError
                     });                     
                 }

                 return false;
             }
         </script>
    </xsl:template>
    
    <xsl:template name="page-subscribe-link-script">
        <xsl:param name="email"/>      
        <script type="text/javascript">
            function page_subscribe_popup_<xsl:value-of select="$uniqueId"/>(mode)
            {
                var title = mode == 'subscribe' ? "<i18n:text i18n:key='PLUGINS_PAGE_SUBSCRIBE_POPUP_SUBSCRIBE_TITLE' i18n:catalogue='plugin.page-subscription'/>" : "<i18n:text i18n:key='PLUGINS_PAGE_SUBSCRIBE_POPUP_UNSUBSCRIBE_TITLE' i18n:catalogue='plugin.page-subscription'/>";
                $j("#page-subscribe-confirm-<xsl:value-of select="$uniqueId"/>").dialog({
                  resizable: false,
                  height: 'auto',
                  width: 'auto',
                  modal: true,
                  title: title,
                  buttons: {
                    <i18n:text i18n:key="PLUGINS_PAGE_SUBSCRIBE_FORM_VALIDATE" i18n:catalogue="plugin.page-subscription"/>: function() {
                      page_subscribe_popup_submit_<xsl:value-of select="$uniqueId"/>(mode, '<xsl:value-of select="$email"/>');
                    },
                    <i18n:text i18n:key="PLUGINS_PAGE_SUBSCRIBE_FORM_CANCEL" i18n:catalogue="plugin.page-subscription"/>: function() {
                      $j( this ).dialog( "close" );
                    }
                  }
                });
            }
        </script>
    </xsl:template>
    
    <xsl:template name="page-subscribe-link-script-submit">
        <script type="text/javascript">      
        function page_subscribe_popup_submit_<xsl:value-of select="$uniqueId"/>(action, email)
        {                    
            // send it in ajax
            var data = {
                "page-id": "<xsl:value-of select="$page-subscribe-page-id"/>",
                "email": email,
                "page-subscribe-action": action,
                "ajax": "true"
            };

            function result(data)
            {
                var s = "";
                $j('errors error', data).each(function () { s += $j(this).text() + "\n"; });
                if (s == "")
                {
                    var errors = $j('error', data);
                    if (errors.size() == 0)
                    {
                        $j("#page-subscribe-confirm-<xsl:value-of select="$uniqueId"/>").dialog("close");
                        $j("#page-subscribe-confirm-" + action + "-<xsl:value-of select="$uniqueId"/>").dialog("close");
                        show_popup_info_<xsl:value-of select="$uniqueId"/>(action);
                    }
                    else
                    {
                        var errorInfo = "";
                        $j.each(errors, function(i) {
                            errorInfo += "\n* " + $j(errors[i]).text();
                        }); 
                        alert("<i18n:text i18n:key="PLUGINS_PAGE_SUBSCRIBE_FORM_ERROR_DESCRIPTION"  i18n:catalogue="plugin.page-subscription"/>" + errorInfo)
                    }
                }
                else
                {
                    alert(s);
                }
            }
            
            function handleError(jqXHR, textStatus, errorThrown)
            {
                alert("<i18n:text i18n:key="PLUGINS_PAGE_SUBSCRIBE_FORM_ERROR_AJAX" i18n:catalogue="plugin.page-subscription"/>");
            }

            $j.ajax({
                url: "<xsl:value-of select="$uri-prefix"/>/plugins/page-subscription/subscribe",
                data: data,
                type: 'post',
                success: result,
                error: handleError
            });                     

            return false;
        }
        </script>
     </xsl:template>
    
    <xsl:template name="page-subscribe-script-cacheable">
       <script type="text/javascript">
        $j("#page-subscribe-form-<xsl:value-of select="$uniqueId"/>").css('display', 'none');
        $j("#page-subscribe-submit-<xsl:value-of select="$uniqueId"/>").css('display', 'none');
        
        function page_subscribe_get_info_user_<xsl:value-of select="$uniqueId"/>()
        {                    
            // send it in ajax
            var data = {
                "page-id": "<xsl:value-of select="$page-subscribe-page-id"/>",
                "siteName": "<xsl:value-of select="$site"/>"
            };
    
            function result(data)
            {
                var users = $j('user', data);
                if (users.attr("isLog") == "true")
                {
                    if (users.attr("isSubscribe") == "false")
                    {
                        $j("#page-subscribe-<xsl:value-of select="$uniqueId"/>").wrapInner("&lt;a href=\"javascript: page_subscribe_popup_subscribe_<xsl:value-of select="$uniqueId"/>('subscribe', '" + users.text() + "')\"&gt;&lt;/a&gt;");
                    }
                    else
                    {
                        $j("#page-subscribe-<xsl:value-of select="$uniqueId"/>").wrapInner("&lt;a href=\"javascript: page_subscribe_popup_subscribe_<xsl:value-of select="$uniqueId"/>('unsubscribe','" + users.text() + "')\"&gt;&lt;/a&gt;");
                    }
                }
                else
                {
                    $j("#page-subscribe-<xsl:value-of select="$uniqueId"/>").wrapInner("&lt;a href=\"javascript: page_subscribe_form_popup_<xsl:value-of select="$uniqueId"/>('subscribe')\"&gt;&lt;/a&gt;");
                }
            }
            
            function handleError(jqXHR, textStatus, errorThrown)
            {
                alert("<i18n:text i18n:key="PLUGINS_PAGE_SUBSCRIBE_FORM_ERROR_AJAX" i18n:catalogue="plugin.page-subscription"/>");
            }
    
            $j.ajax({
                url: "<xsl:value-of select="$uri-prefix"/>/plugins/page-subscription/info-user",
                data: data,
                type: 'post',
                success: result,
                error: handleError
            });                     
        }
        page_subscribe_get_info_user_<xsl:value-of select="$uniqueId"/>();
        
        function page_subscribe_popup_subscribe_<xsl:value-of select="$uniqueId"/>(mode, email)
        {
            $j("#page-subscribe-confirm-" + mode + "-<xsl:value-of select="$uniqueId"/>").dialog({
              resizable: false,
              height: 'auto',
              width: 'auto',
              modal: true,
              title: "<i18n:text i18n:key='PLUGINS_PAGE_SUBSCRIBE_FORM_TITLE' i18n:catalogue='plugin.page-subscription'/>",
              buttons: {
                <i18n:text i18n:key="PLUGINS_PAGE_SUBSCRIBE_FORM_VALIDATE" i18n:catalogue="plugin.page-subscription"/>: function() {
                  page_subscribe_popup_submit_<xsl:value-of select="$uniqueId"/>(mode, email);
                },
                <i18n:text i18n:key="PLUGINS_PAGE_SUBSCRIBE_FORM_CANCEL" i18n:catalogue="plugin.page-subscription"/>: function() {
                  $j( this ).dialog( "close" );
                }
              }
            });
        }
        
        </script>
    </xsl:template>
    
    <xsl:template name="page-subscribe-popup-info-script">
        <script type="text/javascript">
            function show_popup_info_<xsl:value-of select="$uniqueId"/>(mode)
            {
                $j("#page-subscribe-message-" + mode + "-<xsl:value-of select="$uniqueId"/>").dialog({
                  resizable: false,
                  height: 'auto',
                  width: 'auto',
                  modal: true,
                  title: "<i18n:text i18n:key="PLUGINS_PAGE_SUBSCRIBE_FORM_INFO" i18n:catalogue="plugin.page-subscription"/>",
                  buttons: {
                    <i18n:text i18n:key="PLUGINS_PAGE_SUBSCRIBE_FORM_OK" i18n:catalogue="plugin.page-subscription"/>: function() {
                      $j( this ).dialog( "close" );
                      //location.reload();
                    }
                  }
                });
            }
        </script>
    </xsl:template>
    
</xsl:stylesheet>